@@ -4,26 +4,15 @@ import click
 
 from . import __title__, __version__
 
-PYCRYPTODOMEX_INSTALLED = True
 try:
     import Cryptodome
 except ImportError:
     PYCRYPTODOMEX_INSTALLED = False
 else:
+    PYCRYPTODOMEX_INSTALLED = True
     del Cryptodome
 
-PLUGINS = [
-    "crc32",
-    "md5",
-    "sha1",
-    "sha256",
-    "sha512",
-    "sha3-256",
-    "sha3-512",
-    "blake2b",
-    "blake2s",
-]
-
+PLUGINS = ["crc32", "md5", "sha1", "sha256", "sha512", "sha3-256", "sha3-512", "blake2b", "blake2s"]
 LEGACY_PLUGINS = ["md2", "md4", "ripemd160"]
 
 CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
@@ -53,7 +42,7 @@ class Cli(click.MultiCommand):
 @click.command(__title__, cls=Cli, context_settings=CONTEXT_SETTINGS)
 @click.version_option(__version__, prog_name=__title__)
 def main():
-    pass
+    """Generate or check various hash values."""
 
 
 if __name__ == "__main__":
