@@ -142,10 +142,7 @@ class GetHash(object):
 
     def glob_function(self, pathnames):
         return glob_filters(
-            pathnames,
-            mode=self.glob_mode,
-            type=self.glob_type,
-            recursive=self.recursive,
+            pathnames, mode=self.glob_mode, type=self.glob_type, recursive=self.recursive
         )
 
     def hash_function(self, path):
@@ -154,9 +151,12 @@ class GetHash(object):
     def check_root(self, path):
         if self.inplace:
             return os.path.dirname(path)
-        if self.root is not None:
-            return self.root
-        return None
+        return self.root
+
+    def check_sync(self, path, hash_path):
+        if self.sync:
+            t = os.path.getmtime(path)
+            os.utime(hash_path, (t, t))
 
     def generate_hash(self, patterns):
         for path in self.glob_function(patterns):
@@ -165,10 +165,7 @@ class GetHash(object):
                 hash_line = generate_hash_line(path, self.hash_function, root=root)
                 hash_path = path + self.suffix
                 self.output.dump(hash_line, hash_path)
-
-                if self.sync:
-                    t = os.path.getmtime(path)
-                    os.utime(hash_path, (t, t))
+                self.check_sync(path, hash_path)
             except Exception as e:
                 self.echo_error(path, e)
             else:
@@ -180,10 +177,7 @@ class GetHash(object):
             try:
                 root = self.check_root(hash_path)
                 path = check_hash_line(hash_line, self.hash_function, root=root)
-
-                if self.sync:
-                    t = os.path.getmtime(path)
-                    os.utime(hash_path, (t, t))
+                self.check_sync(path, hash_path)
             except CheckHashLineError as e:
                 self.echo(f"[FAILURE] {e.path}", fg="red")
             except Exception as e:
@@ -211,7 +205,6 @@ class GetHash(object):
 def script_main(ctx, files, **options):
     """Generate the body for the main function."""
 
-    # Convert bool flags to streams.
     no_stdout = options.pop("no_stdout", False)
     no_stderr = options.pop("no_stderr", False)
     stdout = open(os.devnull, "w") if no_stdout else sys.stdout
@@ -229,9 +222,7 @@ def gethashcli(cmdname, hashname, suffix):
         path_format = MutuallyExclusiveOptionGroup(
             "Path Format", help="Set the path format in checksum files."
         )
-        output_mode = MutuallyExclusiveOptionGroup(
-            "Output Mode", help="Set the file output mode."
-        )
+        output_mode = MutuallyExclusiveOptionGroup("Output Mode", help="Set the file output mode.")
 
         @click.command(  # type: ignore [call-arg]
             cmdname,
@@ -240,10 +231,7 @@ def gethashcli(cmdname, hashname, suffix):
         )
         @click.argument("files", nargs=-1)
         @click.option(
-            "-c",
-            "--check",
-            is_flag=True,
-            help=f"Read {hashname} from FILES and check them.",
+            "-c", "--check", is_flag=True, help=f"Read {hashname} from FILES and check them."
         )
         @click.option(
             "-d",
@@ -292,28 +280,15 @@ def gethashcli(cmdname, hashname, suffix):
             is_flag=True,
             help="Update mtime of hash files to the same as data files.",
         )
-        @path_format.option(
-            "-i", "--inplace", is_flag=True, help="Use basename in checksum files."
-        )
+        @path_format.option("-i", "--inplace", is_flag=True, help="Use basename in checksum files.")
         @path_format.option(
             "-z",
             "--root",
-            type=click.Path(
-                exists=True,
-                file_okay=False,
-                dir_okay=True,
-                writable=False,
-                readable=False,
-            ),
-            default=None,
+            type=click.Path(exists=True, file_okay=False),
             help="The path field in checksum files is relative to the root directory.",
         )
         @output_mode.option(
-            "-o",
-            "--agg",
-            type=FilePath(suffix=suffix),
-            default=None,
-            help="Set the aggregate output file.",
+            "-o", "--agg", type=FilePath(suffix=suffix), help="Set the aggregate output file."
         )
         @output_mode.option("-s", "--sep", is_flag=True, help="Separate output files.")
         @output_mode.option(
@@ -324,13 +299,11 @@ def gethashcli(cmdname, hashname, suffix):
         )
         @click.option("--start", type=click.INT, help="The start offset of files.")
         @click.option("--stop", type=click.INT, help="The stop offset of files.")
-        @click.option("--tqdm-ascii", type=click.BOOL, default=False, show_default=True)
-        @click.option(
-            "--tqdm-disable", type=click.BOOL, default=False, show_default=True
-        )
-        @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
         @click.option("--no-stdout", is_flag=True, help="Do not output to stdout.")
         @click.option("--no-stderr", is_flag=True, help="Do not output to stderr.")
+        @click.option("--tqdm-ascii", type=click.BOOL, default=False, show_default=True)
+        @click.option("--tqdm-disable", type=click.BOOL, default=False, show_default=True)
+        @click.option("--tqdm-leave", type=click.BOOL, default=False, show_default=True)
         @click.version_option(__version__, prog_name=cmdname)
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
