@@ -12,9 +12,11 @@ def _py_strxor(term1, term2, output=None):
 
 
 try:
-    from Cryptodome.Util.strxor import strxor as _strxor  # NOQA: F811
+    from Cryptodome.Util.strxor import strxor as _c_strxor
 except ImportError:
     _strxor = _py_strxor
+else:
+    _strxor = _c_strxor
 
 
 def strxor(term1, term2, output=None):
